import * as vue from 'vue';
import { UnwrapRef, WritableComputedRef, App, Directive } from 'vue';

/**
 * Translate content according to the current language.
 */
declare const Component: vue.DefineComponent<{
    tag: {
        type: StringConstructor;
        default: string;
    };
    translateN: {
        type: NumberConstructor;
        default: null;
    };
    translatePlural: {
        type: StringConstructor;
        default: null;
    };
    translateContext: {
        type: StringConstructor;
        default: null;
    };
    translateParams: {
        type: ObjectConstructor;
        default: null;
    };
    translateComment: {
        type: StringConstructor;
        default: null;
    };
}, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
    [key: string]: any;
}>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, any, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<{
    tag: string;
    translateN: number;
    translatePlural: string;
    translateContext: string;
    translateParams: Record<string, any>;
    translateComment: string;
} & {}>, {
    tag: string;
    translateN: number;
    translatePlural: string;
    translateContext: string;
    translateParams: Record<string, any>;
    translateComment: string;
}>;

declare type ComponentType = typeof Component;
declare type Message = string | string[];
declare type MessageContext = {
    [context: string]: Message;
};
declare type LanguageData = {
    [messageId: string]: Message | MessageContext;
};
declare type Translations = {
    [language: string]: LanguageData;
};
interface GetTextOptions {
    availableLanguages: {
        [key: string]: string;
    };
    defaultLanguage: string;
    mutedLanguages: Array<string>;
    silent: boolean;
    translations: Translations;
    setGlobalProperties: boolean;
    provideDirective: boolean;
    provideComponent: boolean;
}
declare type Language = UnwrapRef<{
    available: GetTextOptions["availableLanguages"];
    muted: GetTextOptions["mutedLanguages"];
    silent: GetTextOptions["silent"];
    translations: WritableComputedRef<GetTextOptions["translations"]>;
    current: string;
    $gettext: (msgid: string) => string;
    $pgettext: (context: string, msgid: string) => string;
    $ngettext: (msgid: string, plural: string, n: number) => string;
    $npgettext: (context: string, msgid: string, plural: string, n: number) => string;
    interpolate: (msgid: string, context: object, disableHtmlEscaping?: boolean) => string;
    install: (app: App) => void;
    directive: Directive;
    component: ComponentType;
}>;

declare const useGettext: () => Language;

declare function createGettext(options?: Partial<GetTextOptions>): {
    available: {
        [x: string]: string;
    };
    muted: string[];
    silent: boolean;
    translations: {
        [x: string]: {
            [x: string]: Message | {
                [x: string]: Message;
            };
        };
    };
    current: string;
    $gettext: (msgid: string) => string;
    $pgettext: (context: string, msgid: string) => string;
    $ngettext: (msgid: string, plural: string, n: number) => string;
    $npgettext: (context: string, msgid: string, plural: string, n: number) => string;
    interpolate: (msgid: string, context: object, disableHtmlEscaping?: boolean | undefined) => string;
    install: (app: App<any>) => void;
    directive: vue.FunctionDirective<any, any> | {
        created?: vue.DirectiveHook<any, null, any> | undefined;
        beforeMount?: vue.DirectiveHook<any, null, any> | undefined;
        mounted?: vue.DirectiveHook<any, null, any> | undefined;
        beforeUpdate?: vue.DirectiveHook<any, vue.VNode<any, any, {
            [key: string]: any;
        }>, any> | undefined;
        updated?: vue.DirectiveHook<any, vue.VNode<any, any, {
            [key: string]: any;
        }>, any> | undefined;
        beforeUnmount?: vue.DirectiveHook<any, null, any> | undefined;
        unmounted?: vue.DirectiveHook<any, null, any> | undefined;
        getSSRProps?: ((binding: vue.DirectiveBinding<any>, vnode: vue.VNode<vue.RendererNode, vue.RendererElement, {
            [key: string]: any;
        }>) => {
            [x: string]: unknown;
        } | undefined) | undefined;
    };
    component: vue.DefineComponent<{
        tag: {
            type: StringConstructor;
            default: string;
        };
        translateN: {
            type: NumberConstructor;
            default: null;
        };
        translatePlural: {
            type: StringConstructor;
            default: null;
        };
        translateContext: {
            type: StringConstructor;
            default: null;
        };
        translateParams: {
            type: ObjectConstructor;
            default: null;
        };
        translateComment: {
            type: StringConstructor;
            default: null;
        };
    }, () => vue.VNode<vue.RendererNode, vue.RendererElement, {
        [key: string]: any;
    }>, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, any, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<{
        tag: string;
        translateN: number;
        translatePlural: string;
        translateContext: string;
        translateParams: Record<string, any>;
        translateComment: string;
    } & {}>, {
        tag: string;
        translateN: number;
        translatePlural: string;
        translateContext: string;
        translateParams: Record<string, any>;
        translateComment: string;
    }>;
};

export { createGettext, useGettext };
